package de.fraunhofer.iem.dataprovider.configuration

import jakarta.annotation.PostConstruct
import org.springframework.beans.factory.annotation.Value
import org.springframework.boot.context.properties.source.InvalidConfigurationPropertyValueException
import org.springframework.stereotype.Component
import java.net.URL


@Component
class OpenCodeGitlabApiConfig : GitApiConfig {

    @PostConstruct
    fun postConstruct() {
        envIsSet(OPENCODE_GITLAB_URL, host)
        envIsSet(OC_GL_APIKEY, accessToken)
        // There is no try catch block around the operations on purpose!
        // We want to throw here if this operations fail.
        URL(host).toURI()
    }


    @Value("\${$OPENCODE_GITLAB_URL}")
    override lateinit var host: String

    @Value("\${$OC_GL_APIKEY}")
    override lateinit var accessToken: String

    /**
     * Checks whether a given environment variable was initialized properly and throws an
     * @InvalidConfigurationPropertyValueException if the variable was empty.
     */
    private fun envIsSet(envName: String, env: String) {
        if (env.isBlank()) {
            throw InvalidConfigurationPropertyValueException(envName, env, "$env environment variable is not set.")
        }
    }

    companion object {
        private const val OPENCODE_GITLAB_URL = "OPENCODE_GITLAB_URL"
        private const val OC_GL_APIKEY = "OC_GL_APIKEY"
    }
}
